@@ -18,6 +18,7 @@
 #' @param R The number of replications to use for bootstrap.
 #' @param histogram If \code{TRUE}, produces a histogram of bootstrapped values.
 #' @param digits The number of significant digits in the output.
+#' @param ... Additional arguments (ignored).
 #' 
 #' @details For a 2 x 2 table, where a and d are the concordant cells
 #'          and b and c are discordant cells:
@@ -40,11 +41,14 @@
 #'          For tables larger than 2 x 2, the statistics are not directional.
 #'          That is, OR is always >= 1, P is always >= 0.5, and
 #'          g is always positive.  
-#'          Because of this, the confidence interval will
+#'          Because of this, if \code{type="perc"}, the confidence interval will
 #'          never cross the values for no effect 
 #'          (OR = 1, P = 0.5, or g = 0).
-#'          Because of this, the confidence interval range should not
-#'          be used for statistical inference for tables larger than 2 x 2. 
+#'          Because of this, the confidence interval range
+#'          in this case should not
+#'          be used for statistical inference.
+#'          However, if \code{type="norm"}, the confidence interval
+#'          may cross the values for no effect.
 #'          
 #'           When the reported statistics are close to their extremes,
 #'           or with small counts, 
@@ -74,7 +78,7 @@
 cohenG = 
   function(x, ci=FALSE, conf=0.95, type="perc",
            R=1000, histogram=FALSE, 
-           digits=3) {
+           digits=3, ...) {
     
      n = nrow(x)
      m = ncol(x)
